@@ -1,7 +1,7 @@
 /*
  * This file is part of the QPackageKit project
  * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
- * Copyright (C) 2010-2016 Daniel Nicoletti <dantti12@gmail.com>
+ * Copyright (C) 2010-2018 Daniel Nicoletti <dantti12@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -34,6 +34,8 @@
 namespace PackageKit {
 
 class Details;
+struct PkPackage;
+struct PkDetail;
 
 /**
 * \class Transaction transaction.h Transaction
@@ -45,7 +47,7 @@ class Details;
 * A Transaction is created whenever you do an asynchronous action (for example a Search, Install...).
 * This class allows you to monitor and control the flow of the action.
 *
-* You should delete the transaction after finished() is emitted
+* Transaction will be automatically deleted after finished() is emitted
 *
 * \sa Daemon
 */
@@ -130,7 +132,8 @@ public:
         RoleRepairSystem,       // Since 0.7.2
         RoleGetDetailsLocal,    // Since 0.8.17
         RoleGetFilesLocal,      // Since 0.9.1
-        RoleRepoRemove          // Since 0.9.1
+        RoleRepoRemove,         // Since 0.9.1
+        RoleUpgradeSystem       // since 1.0.11
     };
     Q_ENUM(Role)
     typedef Bitfield Roles;
@@ -259,36 +262,14 @@ public:
         FilterNotCollections = 0x0800000,
         FilterApplication    = 0x1000000,
         FilterNotApplication = 0x2000000,
+        FilterDownloaded     = 0x4000000,
+        FilterNotDownloaded  = 0x8000000,
         /* this always has to be at the end of the list */
-        FilterLast           = 0x4000000
+        FilterLast           = 0x10000000
     };
     Q_ENUM(Filter)
     Q_DECLARE_FLAGS(Filters, Filter)
 
-    /**
-     * Describes a message's type
-     */
-    enum Message {
-        MessageUnknown,
-        MessageBrokenMirror,
-        MessageConnectionRefused,
-        MessageParameterInvalid,
-        MessagePriorityInvalid,
-        MessageBackendError,
-        MessageDaemonError,
-        MessageCacheBeingRebuilt,
-        MessageUntrustedPackage,
-        MessageNewerPackageExists,
-        MessageCouldNotFindPackage,
-        MessageConfigFilesChanged,
-        MessagePackageAlreadyInstalled,
-        MessageAutoremoveIgnored,
-        MessageRepoMetadataDownloadFailed,
-        MessageRepoForDevelopersOnly,
-        MessageOtherUpdatesHeldBack
-    };
-    Q_ENUM(Message)
-
     /**
      * Describes the current state of the transaction
      */
@@ -328,7 +309,8 @@ public:
         StatusScanProcessList,
         StatusCheckExecutableFiles,
         StatusCheckLibraries,
-        StatusCopyFiles
+        StatusCopyFiles,
+        StatusRunHook
     };
     Q_ENUM(Status)
 
@@ -355,13 +337,28 @@ public:
 
     /**
      * Describes the type of distribution upgrade to perform
-     * \sa upgradeSystem()
+     * \sa Daemon::upgradeSystem()
+      */
+    enum UpgradeKind {
+        UpgradeKindUnknown,
+        UpgradeKindMinimal,
+        UpgradeKindDefault,
+        UpgradeKindComplete
+    };
+    Q_ENUM(UpgradeKind)
+
+    /**
+     * Describes the type of distribution upgrade to perform
+     * \sa Daemon::upgradeSystem()
      */
     enum TransactionFlag {
-        TransactionFlagNone         = 1 << 0, // Since: 0.8.1
-        TransactionFlagOnlyTrusted  = 1 << 1, // Since: 0.8.1
-        TransactionFlagSimulate     = 1 << 2, // Since: 0.8.1
-        TransactionFlagOnlyDownload = 1 << 3  // Since: 0.8.1
+        TransactionFlagNone           = 1 << 0, // Since: 0.8.1
+        TransactionFlagOnlyTrusted    = 1 << 1, // Since: 0.8.1
+        TransactionFlagSimulate       = 1 << 2, // Since: 0.8.1
+        TransactionFlagOnlyDownload   = 1 << 3,  // Since: 1.0.2
+        TransactionFlagAllowReinstall = 1 << 4,  // Since: 1.0.2
+        TransactionFlagJustReinstall  = 1 << 5,  // Since: 1.0.2
+        TransactionFlagAllowDowngrade = 1 << 6  // Since: 0.8.1
     };
     Q_DECLARE_FLAGS(TransactionFlags, TransactionFlag)
     Q_ENUM(TransactionFlag)
@@ -462,7 +459,8 @@ public:
         InfoPreparing,
         InfoDecompressing,
         InfoUntrusted,
-        InfoTrusted
+        InfoTrusted,
+        InfoUnavailable
     };
     Q_ENUM(Info)
 
@@ -512,9 +510,9 @@ public:
     bool allowCancel() const;
 
     /**
-     * Indicates weither the transaction caller is active or not
+     * Indicates whether the transaction caller is active or not
      *
-     * The caller can be inactive if it has quitted before the transaction finished.
+     * The caller can be inactive if it has quit before the transaction finished.
      *
      * \return true if the caller is active, false else
      */
@@ -587,7 +585,7 @@ public:
     QDateTime timespec() const;
 
     /**
-     * Returns weither the transaction succeded or not
+     * Returns whether the transaction succeded or not
      * \return true if the transaction succeeded, false else
      * \note This function only returns a real value for old transactions returned by getOldTransactions
      */
@@ -601,7 +599,7 @@ public:
     uint duration() const;
 
     /**
-     * Returns some data set by the backend to pass additionnal information
+     * Returns some data set by the backend to pass additional information
      * \return a string set by the backend
      * \note This function only returns a real value for old transactions returned by getOldTransactions
      */
@@ -674,13 +672,6 @@ public:
      */
     static QString packageData(const QString &packageID);
 
-    /**
-     * Returns the package icon from the \p packageID
-     *
-     * @deprecated use Appstream to fetch icons
-     */
-    static QT_DEPRECATED QString packageIcon(const QString &packageID);
-
 Q_SIGNALS:
     void allowCancelChanged();
 
@@ -769,13 +760,6 @@ Q_SIGNALS:
      */
     void finished(PackageKit::Transaction::Exit status, uint runtime);
 
-    /**
-     * Conveys a message sent from the backend
-     *
-     * \p type is the type of the \p message
-     */
-    void message(PackageKit::Transaction::Message type, const QString &message);
-
     /**
      * Emitted when the transaction sends a new package
      */
@@ -846,9 +830,7 @@ protected:
     void connectNotify(const QMetaMethod &signal) override;
 
     /**
-     * This method disconnects from DBus signals
      * \attention Make sure to call this method in inherited classes
-     * otherwise no signals will be disconnected
      */
     void disconnectNotify(const QMetaMethod &signal) override;
 
@@ -869,20 +851,19 @@ private:
     friend class Daemon;
     Q_DECLARE_PRIVATE(Transaction)
     Q_DISABLE_COPY(Transaction)
-    Q_PRIVATE_SLOT(d_func(), void createTransactionFinished(QDBusPendingCallWatcher*))
-    Q_PRIVATE_SLOT(d_func(), void methodCallFinished(QDBusPendingCallWatcher*))
     Q_PRIVATE_SLOT(d_func(), void distroUpgrade(uint type, const QString &name, const QString &description))
     Q_PRIVATE_SLOT(d_func(), void details(const QVariantMap &values))
     Q_PRIVATE_SLOT(d_func(), void errorCode(uint error, const QString &details))
     Q_PRIVATE_SLOT(d_func(), void mediaChangeRequired(uint mediaType, const QString &mediaId, const QString &mediaText))
     Q_PRIVATE_SLOT(d_func(), void finished(uint exitCode, uint runtime))
-    Q_PRIVATE_SLOT(d_func(), void message(uint type, const QString &message))
     Q_PRIVATE_SLOT(d_func(), void Package(uint info, const QString &pid, const QString &summary))
+    Q_PRIVATE_SLOT(d_func(), void Packages(QList<PackageKit::PkPackage>))
     Q_PRIVATE_SLOT(d_func(), void ItemProgress(const QString &itemID, uint status, uint percentage))
     Q_PRIVATE_SLOT(d_func(), void RepoSignatureRequired(const QString &pid, const QString &repoName, const QString &keyUrl, const QString &keyUserid, const QString &keyId, const QString &keyFingerprint, const QString &keyTimestamp, uint type))
     Q_PRIVATE_SLOT(d_func(), void requireRestart(uint type, const QString &pid))
     Q_PRIVATE_SLOT(d_func(), void transaction(const QDBusObjectPath &oldTid, const QString &timespec, bool succeeded, uint role, uint duration, const QString &data, uint uid, const QString &cmdline))
     Q_PRIVATE_SLOT(d_func(), void UpdateDetail(const QString &package_id, const QStringList &updates, const QStringList &obsoletes, const QStringList &vendor_urls, const QStringList &bugzilla_urls, const QStringList &cve_urls, uint restart, const QString &update_text, const QString &changelog, uint state, const QString &issued, const QString &updated))
+    Q_PRIVATE_SLOT(d_func(), void UpdateDetails(const QList<PackageKit::PkDetail> &dets))
     Q_PRIVATE_SLOT(d_func(), void destroy())
     Q_PRIVATE_SLOT(d_func(), void daemonQuit())
     Q_PRIVATE_SLOT(d_func(), void propertiesChanged(QString,QVariantMap,QStringList))
@@ -896,7 +877,6 @@ Q_DECLARE_METATYPE(PackageKit::Transaction::InternalError)
 Q_DECLARE_METATYPE(PackageKit::Transaction::Role)
 Q_DECLARE_METATYPE(PackageKit::Transaction::Error)
 Q_DECLARE_METATYPE(PackageKit::Transaction::Exit)
-Q_DECLARE_METATYPE(PackageKit::Transaction::Message)
 Q_DECLARE_METATYPE(PackageKit::Transaction::Status)
 Q_DECLARE_METATYPE(PackageKit::Transaction::MediaType)
 Q_DECLARE_METATYPE(PackageKit::Transaction::DistroUpgrade)
@@ -909,5 +889,6 @@ Q_DECLARE_METATYPE(PackageKit::Transaction::SigType)
 Q_DECLARE_METATYPE(PackageKit::Transaction::Filter)
 Q_DECLARE_METATYPE(PackageKit::Transaction::TransactionFlags)
 Q_DECLARE_METATYPE(PackageKit::Transaction::Filters)
+Q_DECLARE_METATYPE(PackageKit::Transaction::UpgradeKind)
 
 #endif
